#include <SPI.h>
#include <WiFi.h>
#include <LiquidCrystal.h>
		// 液晶ディスプレイを使うためのライブラリ
LiquidCrystal lcd(12, 11, 5, 4, 3, 2);
		// 液晶ディスプレイで使うピンの設定

char ssid[] = "planexuserwpa"; // Wi-Fi アクセスポイントの名前
char pass[] = "1234567890"; // パスワード
int keyIndex = 0;
int status = WL_IDLE_STATUS;
WiFiServer server(8080);
String text1 = "Hello,_IoT!";
		// 液晶ディスプレイの1 行目に表示させる文字
String text2 = "I'm_Intel_Edison"; // 2行目に表示させる文字

void setup() {
  pinMode(2, OUTPUT); // 出力に設定
  pinMode(3, OUTPUT); // 出力に設定
  pinMode(4, OUTPUT); // 出力に設定
  pinMode(5, OUTPUT); // 出力に設定
  pinMode(11, OUTPUT); // 出力に設定
  pinMode(12, OUTPUT); // 出力に設定
  lcd.begin(16, 2); // 液晶でスプレイの大きさを設定
  Serial.begin(9600);
		// シリアル通信の通信速度を9600bps に設定
  while (!Serial); // シリアル通信が確立するまで待つ
  Serial.println("Edison start");

  while ( status != WL_CONNECTED) {
		// Wi-Fi 接続ができるまで繰り返す
    status = WiFi.begin(ssid, pass); // Wi-Fi で接続
    delay(1000); // 1 秒待つ
  }
  Serial.println(WiFi.localIP());
		// IP をシリアルモニタに表示
  server.begin(); // Wi-Fi 接続の開始
}

void loop() {
  WiFiClient client = server.available();
		// 接続しているクライアントを取得する
  if (client) { // 何か送られてきていれば以下を実行する
    Serial.println("new client");
		// シリアルモニタにnew client と表示
    String currentLine = ""; // 受信データの初期化
    while (client.connected()) {
		// 通信がつながっていれば以下を繰り返す
      if (client.available()) {
		// 何か送られてきていれば以下を実行する
        char c = client.read(); // 1 バイト読み込む
        Serial.write(c); // シリアルモニタにその文字を表示する
        if (c == '\n') { // もし￥n（改行コード）だったら
          Recieve(currentLine);
			// データを解析するためにRecieve 関数へ
          if (currentLine.length() == 0) {
		// 受信データの長さが0 だったら（最終行だったら）
            EdisonBoard(); // EdisonBoard 関数へ
            DisplayHTML(client);
		// 画面表示を更新するためにDisplayHTML 関数へ
            break;
          }
          else { // 受信データがの長さが0 でなかったら受信データを初期化
            currentLine = "";
          }
        }
        else if (c != '\r') { // ￥n でも￥r でもなければ
          currentLine += c; // 受信データをcurrentLine につなげる
        }
      }
    }
    client.stop(); // 通信が終わったときの処理
    Serial.println("client disconnected");
		// シリアルモニタにclient disconnected と表示
  }
  delay(10);
}
//【 通信】
void Recieve(String currentLine)
{
  int n, i;
  char a;
  if (int(currentLine.indexOf("GET /?T1:")) != -1) {
		// 受信データに「GET /?T1:」が含まれていれば
    n = currentLine.indexOf(":");
		//「 :」までの文字数をカウントする
    text1 = ""; // 液晶ディスプレイの1 行目に表示する文字の初期化
    for (i = 0; i < currentLine.length(); i++) {
		//「 :」の後の文字を text1 にコピー
      a = currentLine[n + 1 + i];
      if (a == ' ' || a == '&')
        break; //「 スペース」もしくは「&」があれば終了
      text1 += a;
    }
  }
  if (int(currentLine.indexOf("GET /?T2:")) != -1) {
		// 2 行目に関しての処理
    n = currentLine.indexOf(":");
    text2 = "";
    for (i = 0; i < currentLine.length(); i++) {
      a = currentLine[n + 1 + i];
      if (a == ' ' || a == '&')
        break;
      text2 += a;
    }
  }
  return;
}
//【 回路】リスト 4.7を参照
void EdisonBoard()
{
  lcd.clear(); // 液晶ディスプレイをクリア
  lcd.setCursor(0, 0); // カーソル位置を（0, 0）に設定
  lcd.print(text1); // 1 行目に文字を表示
  lcd.setCursor(0, 1); // カーソル位置を（0, 1）に設定
  lcd.print(text2); // 2 行目に文字を表示
}
//【 画面】リスト 4.8 を参照
void DisplayHTML(WiFiClient client)
{
  client.println("<!DOCTYPE html>");
  client.println("<html>");
  client.println("<head>");
  client.println("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">");
  client.println("<title>LCD</title>");
  client.println("</html>");
  client.println("<body>");
  client.println("<form method=\"get\" action=\"\">");
  client.print(" 液晶ディスプレイに表示する文字<br>");
  client.print(" 半角英数字のみ，半角スペースと＆は不可");
  client.print("<P>");
  client.print(" 上段（16 文字まで）<br>");
  client.print("<input type=\"text\" value=\"" + text1 + "\" name=\"TEXT1\" id=\"text01\" onchange=location.href=\"?T1:\"+ document.getElementById(\"text01\").value><br>");
  client.print(" 下段（16 文字まで）<br>");
  client.print("<input type=\"text\" value=\"" + text2 + "\" name=\"TEXT2\" id=\"text02\" onchange=location.href=\"?T2:\"+ document.getElementById(\"text02\").value><br>");
  client.print("</P>");
  client.println("</form>");
  client.println("</body>");
  client.println("</html>");
}
