#include <SPI.h>
#include <WiFi.h>

char ssid[] = "planexuserwpa"; // Wi-Fi アクセスポイントの名前
char pass[] = "1234567890"; // パスワード
int keyIndex = 0;
int status = WL_IDLE_STATUS;
WiFiServer server(8080);

#define DM 120
double dm[DM];

void setup() {
  Serial.begin(9600); // シリアル通信の通信速度を9600bps に設定
  for (int i = 0; i < DM; i++) // 配列の初期化
    dm[i] = 0;
  while (!Serial); // シリアル通信が確立するまで待つ
  Serial.println("Edison start");

  while ( status != WL_CONNECTED) {
		// Wi-Fi 接続ができるまで繰り返す
    status = WiFi.begin(ssid, pass); // Wi-Fi で接続
    delay(1000); // 1 秒待つ
  }
  Serial.println(WiFi.localIP());// IP をシリアルモニタに表示
  server.begin(); // Wi-Fi 接続の開始
}

void loop() {
  WiFiClient client = server.available();
		// 接続しているクライアントを取得する
  if (client) { // 何か送られてきていれば以下を実行する
    Serial.println("new client");
		// シリアルモニタにnew client と表示
    String currentLine = ""; // 受信データの初期化
    while (client.connected()) {
		// 通信がつながっていれば以下を繰り返す
      if (client.available()) {
		// 何か送られてきていれば以下を実行する
        char c = client.read(); // 1 バイト読み込む
        Serial.write(c); // シリアルモニタにその文字を表示する
        if (c == '\n') { // もし￥n（改行コード）だったら
          Recieve(currentLine);
		// データを解析するためにRecieve 関数へ
          if (currentLine.length() == 0) {
		// 受信データの長さが0 だったら（最終行だったら）
            DisplayHTML(client);
		// 画面表示を更新するためにDisplayHTML 関数へ
            break;
          }
          else { // 受信データがの長さが0 でなかったら受信データを初期化
            currentLine = "";
          }
        }
        else if (c != '\r') { // ￥n でも￥r でもなければ
          currentLine += c; // 受信データをcurrentLine につなげる
        }

      }
    }
    client.stop(); // 通信が終わったときの処理
    Serial.println("client disconnected");
		// シリアルモニタにclient disconnected と表示
  }
  delay(100);
  EdisonBoard(); // EdisonBoard 関数へ
}
//【 通信】自動更新時は操作するための情報がないため空
void Recieve(String currentLine)
{
}
//【 回路】リスト 4.19 を参照
void EdisonBoard()
{
  for (int i = 0; i < DM - 1; i++) { // 配列をずらす
    dm[i] = dm[i + 1];
  }
  double sensorReading = analogRead(0) * 5 * 100
    / 1024; // 値を読み込む
  dm[DM - 1] = sensorReading; // 配列の最後に温度を追加する
}
//【 画面】リスト 4.20 を参照
void DisplayHTML(WiFiClient client)
{
  client.println("HTTP/1.1 200 OK");
  client.println("Content-Type: text/html");
  client.println("Connection: close");
  client.println("Refresh: 1");
		// 1 秒おきに更新する設定
  client.println();
  client.println("<!DOCTYPE html>");
  client.println("<html>");
  client.println("<head>");
  client.println("<title>センサの値をグラフにする</title>");
  client.println("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">");
  client.println("<script type=\"text/javascript\">");
  client.println("<!--");
  client.println("function test() {");
  client.println(" var canvas = document.getElementById('sample'); ");
  client.println(" if (canvas.getContext) {");
  client.println(" var context = canvas.getContext('2d');");
  client.println(" context.strokeStyle =\"rgb(0, 0, 0)\";");
  client.println(" context.beginPath();");
  for (int i = 0; i < DM; i++) {
    if (i == 0)
      client.println(" context.moveTo(");
    else
      client.println(" context.lineTo(");
    client.println(i * 2 + 20);
    client.println(",");
    client.println(20 + dm[i]);
    client.println(");");
  }
  client.println(" context.stroke();");
  client.println(" }");
  client.println("}");
  client.println("//-->");
  client.println("</script>");
  client.println("</head>");
  client.println("<body onLoad=\"test()\">");
  client.println("<h2> キャンバスでグラフを描く</h2>");
  client.println("<canvas width=\"300\" height=\"150\" id=\"sample\" style=\"background-color:rgb(224,224,224);\">");
  client.println("</canvas>");
  client.println("</body>");
  client.println("</html>");
}
